//   Copyright 2020 Esri
//   Licensed under the Apache License, Version 2.0 (the "License");
//   you may not use this file except in compliance with the License.
//   You may obtain a copy of the License at
//
//   https://www.apache.org/licenses/LICENSE-2.0
//
//   Unless required by applicable law or agreed to in writing, software
//   distributed under the License is distributed on an "AS IS" BASIS,
//   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
//   See the License for the specific language governing permissions and
//   limitations under the License.
//

#include "Display_device_location.h"

#include "Map.h"
#include "MapQuickView.h"

using namespace Esri::ArcGISRuntime;

Display_device_location::Display_device_location(QObject* parent /* = nullptr */):
    QObject(parent),

    m_map(new Map(BasemapStyle::ArcGISTopographic, this))
{
}

Display_device_location::~Display_device_location()
{
}

MapQuickView* Display_device_location::mapView() const
{
    return m_mapView;
}

void Display_device_location::startLocation()
{
    // start location display
    m_mapView->locationDisplay()->start();
    // center the location display around the device location
    m_mapView->locationDisplay()->setAutoPanMode(LocationDisplayAutoPanMode::Recenter);
}

// Set the view (created in QML)
void Display_device_location::setMapView(MapQuickView* mapView)
{
    if (!mapView || mapView == m_mapView)
    {
        return;
    }

    m_mapView = mapView;
    m_mapView->setMap(m_map);

    startLocation();

    emit mapViewChanged();
}

